@@ -1,6 +1,6 @@
 /* A view which displays a bar plot.
  *
- * Copyright (c) 2003 Ole Laursen.
+ * Copyright (c) 2003, 04 Ole Laursen.
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -41,7 +41,7 @@ public:
   
 private:
   virtual void do_update();
-  virtual void do_attach(Monitor *monitor, const Glib::ustring &mon_dir);
+  virtual void do_attach(Monitor *monitor);
   virtual void do_detach(Monitor *monitor);
   virtual void do_draw_loop();
 
