@@ -207,10 +207,13 @@ Monitor *ChooseMonitorWindow::run(const Glib::RefPtr<Gnome::Conf::Client> &clien
     v = client->get(mon_dir + "/cpu_no");
     if (v.get_type() == Gnome::Conf::VALUE_INT) {
       int no = v.get_int();
-      if (no >= 0 || no < CpuUsageMonitor::max_cpu_no) {
+      if (no >= 0 && no < CpuUsageMonitor::max_cpu_no) {
 	one_cpu_radiobutton->set_active();
 	cpu_no_spinbutton->set_value(no + 1);
       }
+      else {
+	all_cpus_radiobutton->set_active();
+      }
     }
 
     // fill in disk usage info
