@@ -1,6 +1,6 @@
 /* The various system statistics - adapters of the libgtop interface.
  *
- * Copyright (c) 2003, 04 Ole Laursen.
+ * Copyright (c) 2003, 04, 05 Ole Laursen.
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -537,20 +537,20 @@ double DiskUsageMonitor::do_measure()
 
   glibtop_get_fsusage(&fsusage, mount_dir.c_str());
 
-  max_value = fsusage.blocks;
+  max_value = fsusage.blocks * fsusage.block_size;
+
+  double v = 0;
   
   if (show_free) {
     if (fsusage.bavail > 0)
-      return fsusage.bavail * fsusage.block_size;
-    else
-      return 0;
+      v = fsusage.bavail * fsusage.block_size;
   }
   else {
     if (fsusage.blocks > 0)
-      return (fsusage.blocks - fsusage.bfree) * fsusage.block_size;
-    else
-      return 0;
+      v = (fsusage.blocks - fsusage.bfree) * fsusage.block_size;
   }
+  
+  return v;
 }
 
 double DiskUsageMonitor::max()
@@ -921,6 +921,8 @@ double Sensors::get_value(int chip_no, int feature_no)
 // class TemperatureMonitor
 //
 
+double const Sensors::invalid_max = -1000000;
+
 TemperatureMonitor::TemperatureMonitor(int no)
   : sensors_no(no)
 {
