@@ -1,6 +1,6 @@
 /* Implementation of the various system statistics.
  *
- * Copyright (c) 2003, 04 Ole Laursen.
+ * Copyright (c) 2003, 04, 05 Ole Laursen.
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -230,7 +230,7 @@ class Sensors: noncopyable
 public:
   static Sensors &instance();
 
-  static double const invalid_max = -1000000;
+  static double const invalid_max;
   
   struct FeatureInfo
   {
