@@ -590,9 +590,9 @@ bool PreferencesWindow::on_closed(GdkEventAny *)
 
 Monitor *PreferencesWindow::run_choose_monitor_window(const Glib::ustring &str)
 {
-  ChooseMonitorWindow window(applet.get_icon(), *window);
+  ChooseMonitorWindow chooser(applet.get_icon(), *window);
   
-  return window.run(applet.get_gconf_client(), str);
+  return chooser.run(applet.get_gconf_client(), str);
 }
 
 void PreferencesWindow::add_to_monitors_list(Monitor *mon)
