@@ -1,6 +1,6 @@
 /* Implementation of view base class.
  *
- * Copyright (c) 2003 Ole Laursen.
+ * Copyright (c) 2003, 04 Ole Laursen.
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +20,8 @@
 
 #include "view.hpp"
 
-View::View()
+View::View(bool kh)
+  : keeps_history(kh)
 {
 }
 
@@ -39,9 +40,9 @@ void View::update()
   do_update();
 }
 
-void View::attach(Monitor *monitor, const Glib::ustring &mon_dir)
+void View::attach(Monitor *monitor)
 {
-  do_attach(monitor, mon_dir);
+  do_attach(monitor);
 }
 
 void View::detach(Monitor *monitor)
